function initDataTables(options) {

  'use strict';

  var slctr = '.datatable';
  var dtNodes = document.querySelectorAll(slctr);
  if (!dtNodes || !dtNodes.length) {
    return;
  }

  var domDefault = 'full';
  var dom_types = {
    mini: 'tip',
    small: 'lpT<"clear">tip',
    medium: 'T<"clear">lrtip',
    full: '<"dt-toolbar-top"flpT>t<"dt-toolbar-bottom"ip>'
  };

  var pageLength = options && options.pageLength ? options.pageLength : 10;
  var dom = (options && options.dom && dom_types[options.dom]) ? dom_types[options.dom] : dom_types[domDefault];

  var dtOptions = {
    language: {
      "sProcessing": "Procesando...",
      "sLengthMenu": "Mostrar _MENU_",
      "sZeroRecords": "No se encontraron resultados",
      "sEmptyTable": "Ningún dato disponible en esta tabla",
      "sInfo": "_START_ al _END_ de un total de _TOTAL_",
      "sInfoEmpty": "0 registros",
      "sInfoFiltered": "(filtrado de un total de _MAX_)",
      "sInfoPostFix": "",
      "sSearch": "&#x1F50D;",
      "sUrl": "",
      "decimal": ",",
      "sInfoThousands": ".",
      "sLoadingRecords": "Cargando...",
      "oPaginate": {
        "sFirst": "&laquo;",
        "sLast": "&raquo;",
        "sNext": "&raquo;",
        "sPrevious": "&laquo;"
      },
      "oAria": {
        "sSortAscending": ": ordenar de manera ascendente",
        "sSortDescending": ": ordenar de manera descendente"
      }
    },
    processing: true,
    deferRender: true,
    lengthMenu: [5, 10, 15, 20, 30, 50, 100, 250, 500],
    pageLength: pageLength,
    dom: dom,
    fixedColumns: true
  };

  /* global jQuery */
  jQuery(function ($) {

    $(dtNodes).each(function () {
      var nd = $(this);
      if (typeof(nd) !== 'object') {
        return;
      }
      if ($(nd).data('source') && $(nd).data('source').length) {
        _populateData($(nd).data('source'), dtOptions, nd);
      }
    });

    function _populateData(data_source, dtOptions, nd) {

      if (!$.fn.dataTable || $.fn.dataTable.isDataTable(nd)) {
        return;
      }

      var dataSource = window[data_source] ? window[data_source] : null;
      if (!dataSource || !dataSource.length) {
        $(nd).parent().html('<p class="ow-no-rows">No hay redirecciones todavía.</p>');
        return;
      }

      dtOptions.columns = [];

      if (nd.find('th') && nd.find('th').length) {
        nd.find('th').each(function () {
          dtOptions.columns.push({
            title: this.textContent,
            name: this.getAttribute('data-col'),
            actions: this.getAttribute('data-actions')
          });
        });
      } else {
        var i = 0;
        Object.keys(dataSource[0]).forEach(function (name) {
          dtOptions.columns.push({title: name, actions: ''});
          i++;
        });
      }

      dtOptions.data = [];
      dataSource.forEach(function (item) {
        var dtItem = {};
        dtOptions.columns.forEach(function (col) {
          var col_name = col.name ? col.name : (col.title ? col.title : '');
          var col_value = (col_name && item[col_name]) ? item[col_name] : '';

          // Encode to HTML chars (accents become &aacute; and so on, this way datatables sorting works ok)
          if (col_value && col_value.length && col_value.indexOf('<') === -1 && col_value.indexOf('>') === -1) {
            col_value = col_value.replace(/[\u00A0-\u9999<>\&]/g, function (i) {
              return '&#' + i.charCodeAt(0) + ';';
            });
          }
          dtItem[col_name] = col_value;
        });
        var row = Object.values(dtItem);
        if (row.length && row[0] !== '') {
          dtOptions.data.push(row);
        }
      });

      if (dtOptions.data && dtOptions.data.length) {
        _render(nd);
      }
    }

    function _render(nd) {
      nd.css('position', 'static').css('visibility', 'visible');
      nd.on('draw.dt', function () {
        _applyThClassesToTd(nd);
        nd.removeClass(slctr.substring(1));
      }).dataTable(dtOptions);
    }

    function _applyThClassesToTd(nd) {
      if (!nd.find('tr') || !nd.find('tr').length) {
        return;
      }
      var thClasses = [];
      nd.find('th').each(function () {
        thClasses.push( (this.getAttribute('class')).trim() );
      });
      nd.find('tr').each(function () {
        var tr = this;
        var n = 0;
        tr.childNodes.forEach(function (td) {
          if (td.nodeName === '#text') {
            return;
          }
          td.setAttribute('class', thClasses[n]);
          n++;
        });
      });
    }

  });

}
